==> tecfy_core_package-0.1.36.tar.gz: lib/views/components/home/app_bar_profile.dart <==
part of tecfy_core_client_package;

class AppBarProfile extends StatelessWidget {
  final String title;
  final Widget bottomBar;
  final List<Widget> actions;
  final String photoUrl;
  final void Function() onPress;
  AppBarProfile(this.title, {this.bottomBar,this.actions,this.photoUrl,this.onPress});

  @override
  Widget build(BuildContext context) {
    return Container(
        padding: EdgeInsets.only(top: 30.0),
        color: Colors.white,
        height:bottomBar == null ? 110.0 : 160.0,
        child: bottomBar == null
            ? titleBar(context)
            : Column(
                children: <Widget>[ Container(height: 80.0,child: titleBar(context)), bottomBar ?? Container()],
              ));
  }

  titleBar(context) {
    return Row(children: <Widget>[
      GestureDetector(
          onTap: onPress ?? () => AppNavigator.navigateTo(context, () => SettingPage()),
          child: Container(
              width: 70.0,
              height: 100.0,
              child: Stack(
                children: <Widget>[
                  Image.asset(
                    'assets/images/profile back.png',
                    fit: BoxFit.fill,
                    width: 70.0,
                    height: 100.0,
                  ),
                  Padding(
                      padding: EdgeInsets.only(top: 15.5, left: 17),
                      child: CircleAvatar(
                        minRadius: 24.5,
                        maxRadius: 24.5,
                        backgroundColor: Colors.white,
                        backgroundImage: NetworkImage(photoUrl ?? // ConfigService.user?.url ??
                            'https://upload.wikimedia.org/wikipedia/commons/7/7c/Profile_avatar_placeholder_large.png'),
                      ))
                ],
              ))),
      
      //SizedBox(width: 70.0),
      Expanded(
          child: Text(title,
              textAlign: TextAlign.center,
              style: TextStyle(
                  color: ThemeService.mainColor,
                  fontSize: 20.0,
                  fontWeight: FontWeight.w600))),
      // IconButton(
      //     onPressed: () {},
      //     icon: Icon(Icons.search,
      //         size: 35.0, color: ThemeService.mainColor)),
      actions != null && actions.length >0 ? actions.first :SizedBox(width: 70.0),
      actions != null && actions.length >1 ? actions.last :Container(),
      SizedBox(width: 20.0)
      
    ]);
  }
}

==> tecfy_core_package-0.1.100.tar.gz: lib/views/components/home/app_bar_profile.dart <==
part of tecfy_core_client_package;

class AppBarProfile extends StatelessWidget {
  final String title;
  final Widget bottomBar;
  final List<Widget> actions;
  final String photoUrl;
  final void Function() onPress;
  AppBarProfile(this.title,
      {this.bottomBar, this.actions, this.photoUrl, this.onPress});

  @override
  Widget build(BuildContext context) {
    return Container(
        padding: EdgeInsets.only(top: 30.0),
        color: Colors.white,
        height: bottomBar == null ? 110.0 : 160.0,
        child: bottomBar == null
            ? titleBar(context)
            : Column(
                children: <Widget>[
                  Container(height: 80.0, child: titleBar(context)),
                  bottomBar ?? Container()
                ],
              ));
  }

  titleBar(context) {
    return Row(children: <Widget>[
      GestureDetector(
          onTap: onPress ??
              () => AppNavigator.navigateToNamed(context, '/setting'),
          child: Container(
              width: 70.0,
              height: 100.0,
              child: Stack(
                children: <Widget>[
                  Image.asset(
                    'assets/images/profile back.png',
                    fit: BoxFit.fill,
                    width: 70.0,
                    height: 100.0,
                  ),
                  Padding(
                      padding: EdgeInsets.only(top: 15.5, left: 17),
                      child: CircleAvatar(
                        minRadius: 24.5,
                        maxRadius: 24.5,
                        backgroundColor: Colors.white,
                        backgroundImage: NetworkImage(
                            photoUrl ?? // ConfigService.user?.url ??
                                'https://upload.wikimedia.org/wikipedia/commons/7/7c/Profile_avatar_placeholder_large.png'),
                      ))
                ],
              ))),

      //SizedBox(width: 70.0),
      Expanded(
          child: Text(title,
              textAlign: TextAlign.center,
              style: TextStyle(
                  color: ThemeService.mainColor,
                  fontSize: 20.0,
                  fontWeight: FontWeight.w600))),
      // IconButton(
      //     onPressed: () {},
      //     icon: Icon(Icons.search,
      //         size: 35.0, color: ThemeService.mainColor)),
      actions != null && actions.length > 0
          ? actions.first
          : SizedBox(width: 70.0),
      actions != null && actions.length > 1 ? actions.last : Container(),
      SizedBox(width: 20.0)
    ]);
  }
}
